%define python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")

%define debug_package %{nil}

Summary:	fiwalk - find and extract files of a given type

Packager:	Lawrence R. Rogers (lrr@cert.org)

Vendor:		cert.org
Name:		fiwalk
Version:	0.6.16
Release:	3%{?dist}

License:	GPL

Group:		Applications/Forensics Tools
Source:		%{name}-%{version}.tar.gz
Patch0:		%{name}-%{version}-patch-001

BuildRoot:	%{_tmppath}/rpm-root-%{name}-v%{version}
BuildRequires:	%{__python}
BuildRequires:	sleuthkit >= 4.0.0
BuildRequires:	sleuthkit-devel >= 4.0.0
BuildRequires:	gcc-c++
BuildRequires:	openssl-devel
%if 0%{?rhel} != 5
BuildRequires:	file-devel
%else
BuildRequires:	file
%endif
Requires:	%{__python}
Requires:	sleuthkit >= 4.0.0
Requires:	sleuthkit-libs >= 4.0.0

%description
fiwalk is a program that processes a disk image using the SleuthKit
library and outputs its results in Digital Forensics XML, the Attribute
Relationship File Format (ARFF) format used by the Weka Datamining
Toolkit, or an easy-to-read textual format.

The fiwalk source code comes with fiwalk.py, a Python module that makes
it easy to create digital forensics programs. Also included are several
demonstration programs that use fiwalk.py:
	* iblkfind.py – Given a disk block in a disk image, this program
	  tells you which file(s) map that sector.
	* icarvingtruth.py - Given two or more images of the same disk
	  at different points in time, this program files that are present
	  in the earlier images that can only be recovered from the later
	  images using file carving techniques.
	* idifference.py - Given two or more images of the same disk at
	  different points in time, this program tells you what changes
	  took place between each one.
	* iextract.py - Allows the extraction of files that match a
	  particular pattern.
	* igrep.py - Searches every file in a disk image for a particular
	  string. When found, prints, the file and the offset within the
	  file that the string was found.
	* ihistogram.py – Prints a histogram of file types found in the disk image.
	* imap.py - Displays a “map” of where files are present in
	  the disk image.
	* imicrosoft_redact.py - Modifies a disk image of a bootable
	  Microsoft operating system so that the image can no longer be
	  boot and so that any Microsoft copyrighted file in the \Windows
	  directory cannot be executed. This allows the disk image of a
	  Microsoft operating system to be distributed without implicitly
	  violating Microsoft’s copyright.
	* iredact.py - An experimental disk redaction program which
	  allows the removal of specific files matching specific criteria.
	* iverify.py – Given a disk image and a previously created
	  XML file, verifies that each file in the DFXML file is still
	  present in the disk image.
	* sanitize_xml.py - Given a DFXML file, sanitize file names so
	  that no personally identifiable information is leaked if the
	  DFXML file is distributed.

%prep
%setup 
%patch0 -p1

%build
%configure
%{__make}

%install
%makeinstall
mkdir -p %{buildroot}%{python_sitelib}/%{name}
cd python
%__install -m 644 fiwalk.py  %{buildroot}%{python_sitelib}/%{name}
for file in *.py
do
	if [ "$file" != "fiwalk.py" ]; then
		T=fiw-`basename $file .py`
		%__install -m 755 $file %{buildroot}/%{_bindir}/$T
	fi
done
rm %{buildroot}/%{_bindir}/fiwalk
rm %{buildroot}/%{_bindir}/jpeg_extract

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-, root, root, 0755)
%doc COPYING INSTALL NEWS TODO AUTHORS ChangeLog README 
%attr(644, root, root)	%{python_sitelib}/%{name}/*
%attr(755, root, root)	%{_bindir}/*

%changelog
* Tue Feb  5 2013 Lawrence R. Rogers <lrr@cert.org> 0.6.16-3
* Release 0.6.16-3
	Rebuilt with the sleuthkit 4.0.2 which includes fiwalk and jpeg_extract, both of which are removed from this installation

* Mon Nov 26 2012 Lawrence R. Rogers <lrr@cert.org> 0.6.16-2
* Release 0.6.16-2
	Rebuilt with the sleuthkit 4.0.1

* Fri Dec 2 2011 Simson Garfinkel  <simsong@mncrnpsedu.local> 0.6.16-1
* Release 0.6.16-1
	* xml.cpp: moved library versions from xml.h to xml.cpp
	  (xml::add_DFXML_build_environment): now includes exiv2 version in dfxml output
	* xml.cpp (printf): added #ifdef GNUC_HAS_DIAGNOSTIC_PRAGMA to allow compiling with older GCC
	* python/ireport.py: renamed from istats and changed to work with dfxml
	* python/Makefile.am (EXTRA_DIST): Changed istats to ireport.
	* python/dfxml.py (fileobjects_iter): replaced iteritems() with items() to allow for migration to Python 3.
	  Replaced unicode() with "" for migration to Python 3.

* Wed Jul 17 2011 Simson Garfinkel  <simsong@mncrnpsedu.local> 0.6.15-1
* Release 0.6.15-1
	* configure.ac: upgraded fiwalk to version 0.6.15
	* src/fiwalk_tsk.cpp (file_act): now combines 512-byte segments from compressed files.
	* python/fiwalk.py (fileobjects_using_sax): fixed fileobjects_using_sax
	* dfxml.py (fileobject_reader.__init__): no longer errors on hashdigests not located in fileobjects
	* configure.ac: rewrote test to handle obsolete version of AFFLIB in MacPorts.

* Mon May 11 2011 Simson Garfinkel  <simsong@Alphonse-Mucha.local> 0.6.12-1
* Release 0.6.12-1
	* configure.ac: upgraded fiwalk to version 0.6.12
	* xml.cpp (mkstemp): changed mkstemp linkage so it's a C program.
	* python/dfxml.py (volumeobjects_sax): byterun class renamed byte_run to match new DFXML spec.
	* src/xml.h: added time.h. Fixed DFXML to output compile date in ISO8601 time.
	* src/fiwalk.cpp (file_infot): time format changed to ISO 8601 for XML output.
	* src/content.cpp (content::write_record): all <run> tags changed to <byte_run>
	* src/xml.h (class xml): version 1.0 added to creator
	* src/fiwalk.cpp: namespace changed to http://www.forensicswiki.org/wiki/Category:Digital_Forensics_XML
	* dfxml version changed to 1.0
	* xml.cpp: changed #ifdef WIN to appropriate #ifdefs
	* xml.h (class xml): changed #ifdef WIN to appropriate #ifdefs
* Mon Apr 6 2011 Simson Garfinkel  <simsong@imac3.home> 0.6.11-1
* Release 0.6.11-1
	* configure.ac: incremented version number to 0.6.11.
	* hash_t.h final(): if final() is called before initialized, init! 
	* src/test_fiwalk.sh (IMG): updated test so that it returns 0 if $IMG is not on the system, rather than failing.

* Mon Mar 20 2011 Simson Garfinkel  <simsong@imac3.home> 0.6.9-1
* Release 0.6.9-1
	* configure.ac: added -Wall and -D_FORTIFY_SOURCE=2 
	* increase version number to 0.6.9
	* configure.ac: changed search for -lcrypto from MD5_Update to EVP_md5
	* src/fiwalk.h: significantly rearranged the #include files so that all of the /usr/include/*.h files are included,
	  then the /usr/include/sys/*.h, then the C++ files. This seems to handle some strange errors we were getting.
	* configure.ac: removed -lewf -lz push into LIBS. It doesn't give you luck if the libewf library is not present.
	* src/content.cpp: removed __PRI64_PREFIX define for Weird Linux Bug
	* src/unicode_escape.cpp: added #include <stdint.h>
	* src/unicode_escape.cpp (UTF8BufferToUTF32Buffer): changed unsigned long * to uint32_t *
	  (validateOrEscapeUTF8): changed unsigned long to uint32_t
	* src/lua_utf8.c (sarn_utf8_code_func): replaced unsigned long int with uint32_t
	* src/fiwalk.cpp: -s option removed because it causes problems on big disks.
	* src/content.cpp: removed my_evp_md(const char *str)
	  (content::open_savefile): unable to open save file is no longer a fatal error.

* Mon Mar 14 2011  Simson Garfinkel  <simsong@imac3.home> 0.6.7-1
* Release 0.6.7-1
	* configure.ac: increased version number to 0.6.7
	* python/idifference.py: relevant_filenames removed.
	  (DiskState.print_fi2.prtime): extensively rewrote for improved performance. Removed numerous typos. Now makes ZIP or TAR files.
	* python/dfxml.py (fileobject_reader._end_element): modified to allow either <fiwalk> or <dfxml> by ignoring tag type in _end_element()
	* xml.h: added HAVE_SYS_RESOURCE_H

* Mon Feb 23 2011 Simson Garfinkel  <simsong@imac3.home> 0.6.6-1
* Release 0.6.6-1
	* configure.ac: increased version number to 0.6.6
	* src/fiwalk.cpp: added -GXX option to suppress hash calculation on files larger than XX GB.
	* src/test_fiwalk.sh: now validates XML
	* src/fiwalk.cpp: added option -Gnn to specify a maximum gigabyte size of files larger than which won't be processed for content. Default filesize is 2GB.
	* src/fiwalk.cpp: now calls x->open() before reading the config file.
	* src/fiwalk.h: removed opt_multithreaded.
	* src/content.cpp: removed evp_md5 stuff
	* src/fiwalk.cpp: libmagic is now disabled by default
	  outer tag changed from <fiwalk> to <dfxml>
